Cheshire3 Object Model - Document
=================================

.. _objects-document-api:

API
---

.. autoclass:: cheshire3.baseObjects.Document
   :members:


.. _objects-document-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.document.StringDocument
